function M = loadshape_minimal(shape_path,opts)



if (nargin < 2)
    opts = struct;
    opts.shuffle = true;
    opts.calcDist = true;
%     opts.lumped = true;
end

% if (~isfield(opts,'K'))
%     opts.K = 200;
% end


assert(exist(shape_path,'file')==2,'shape file does not exist')

[shape_folder, name, ext] = fileparts(shape_path);

M.name = name;
switch ext
    case '.vert'
        [M.TRIV, M.VERT] = loadTosca(shape_path);
    case '.tri'
        [M.TRIV, M.VERT] = loadTosca(shape_path);
    case '.off'
        [M.TRIV, M.VERT] = loadOff(shape_path);
    case ''
        disp('No extension given, assuming TOSCA format')
        [M.TRIV, M.VERT] = loadTosca(shape_path);
    case '.ply'
        [Tri,Pts] = ply_read(shape_path,'tri');
        M.TRIV = Tri';
        M.VERT = Pts';
    otherwise
        error('Format not supportet: %s\n',ext);
end

M.n = length(M.VERT);
% opts.K = min(opts.K,M.n-1);



% Shuffling the vertices
if (isfield(opts,'shuffle') && opts.shuffle)
    perm = randperm(M.n);
    M.gt(perm) = 1:M.n;
    M.gti = perm;
    M.VERT = M.VERT(perm,:);
    M.TRIV = M.gt(M.TRIV);
else
    M.gt = 1:M.n;
    M.gti = 1:M.n;
end

% Calculate distances
if (isfield(opts,'calcDist') && opts.calcDist)
    M.Gamma = calc_dist_mat(M.VERT,M.TRIV);
    [ M.fps , M.sradius ] = metricfps_new( M.n, M.Gamma);
end

% M.k = opts.K;
M.m = length(M.TRIV);

% Bilinearforms, Laplacian decomposition
% [M.M,M.S] = laplacian(M.VERT,M.TRIV);
% if (isfield(opts,'lumped') && opts.lumped)
%    M.M = sparse(1:M.n,1:M.n,sum(M.M));
% end


M.tri_areas = facearea(M.VERT,M.TRIV);
M.area = sum(M.tri_areas);


% 
end




